Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type TokenType ¶
type TokenType int
const ( LexError TokenType = iota - 1 String RawString Int Float Ident SpecialChar // This is a separator => if Token.Type > SpecialChar && Token.Type < Keyword {...} Semicolon Period Equal LParen RParen LBracket RBracket LBrace RBrace Plus Hyphen Asterisk Greater Less Keyword // This is a separator => if Token.Type > Keyword {...} Select Delete Create Update Insert From Into Table Set Values Where If Exists Not And Or )
Click to show internal directories.
Click to hide internal directories.